# #! /usr/bin/env python3

# from diagnosticism.contingent_reporting import abort
# from diagnosticism.contingent_reporting import conrep
# from diagnosticism.contingent_reporting import set_default_trailing_prompt
# from diagnosticism.program_name import set_program_name

# import unittest
# from unittest.mock import patch

# try:

#     from StringIO import StringIO
# except ImportError:

#     from io import StringIO


